Anchor layout — Kivy v1.0.1-dev documentation

# Anchor layout

This layout align his children to a border or a center: top, left, center, right...

class `kivy.uix.anchorlayout.` `AnchorLayout`(**kwargs)

  Bases: `kivy.uix.layout.Layout`

  Anchor layout class. See module documentation for more informations.

  `anchor_x`

    Horizontal anchor.

    `anchor_x` is an `OptionProperty`, default to ‘center’. Can take a value of ‘left’, ‘center’ or ‘right’

  `anchor_y`

    Vertical anchor.

    `anchor_y` is an `OptionProperty`, default to ‘center’. Can take a value of ‘top’, ‘center’ or ‘bottom’

  `padding`

    Padding between widget box and children, in pixels.

    `padding` is a `NumericProperty`, default to 0.